Django Image Tools
==================

.. image:: https://travis-ci.org/bonsaistudio/django-image-tools.svg?branch=master

.. image:: https://pypip.in/version/django-image-tools/badge.png

.. image:: https://pypip.in/license/django-image-tools/badge.png

.. image:: https://pypip.in/download/django-image-tools/badge.png

.. image:: https://coveralls.io/repos/bonsaistudio/django-image-tools/badge.png

Django Image Tools is a small app that will allow you to manage your project's images without worrying much about image sizes, how to crop them, etc..
All you have to do is to define your website sizes and filters and the app will do the rest for you.

Check out the `official docs on readthedocs! <http://django-image-tools.readthedocs.org/en/latest/>`_ 

Django Image Tools uses Travis CI to test the integration with several versions of Python and Django.
You can see the list of currently supported combinations on our `Travis CI page
<https://travis-ci.org/bonsaistudio/django-image-tools/>`_.

